/*****************************************************************************
 *  Buttons
 *****************************************************************************
 * FileName:        button.c
 * Dependencies:    system.h
 * Processor:       PIC24
 * Compiler:       	MPLAB C30
 * Linker:          MPLAB LINK30
 * Company:         Microchip Technology Incorporated
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the "Company") is intended and supplied to you, the Company's
 * customer, for use solely and exclusively with products manufactured
 * by the Company. 
 *
 * The software is owned by the Company and/or its supplier, and is 
 * protected under applicable copyright laws. All rights are reserved. 
 * Any use in violation of the foregoing restrictions may subject the 
 * user to criminal sanctions under applicable laws, as well as to 
 * civil liability for the breach of the terms and conditions of this 
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES, 
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED 
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT, 
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR 
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * Buttons processing
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * thk                 1/24/09		adopted from HP16 modified for used with LCD mux  
 *thk 				1/24/09			added button five for backlight on/off
 *****************************************************************************/
#include "system.h"

unsigned char BL_ON =0;
extern unsigned char AdcFlag;
extern unsigned char LightShowFlag;
extern unsigned char ClockFlag;

/*****************************************************************************
 * Structure: BUTTONS _button_press
 *
 * Overview: the structure provides a n access to button bit indicators.
 *
 *****************************************************************************/
unsigned char _b1_cnt;
unsigned char _b2_cnt;
unsigned char _b3_cnt;
unsigned char _b4_cnt;
unsigned char _b5_cnt;
BUTTON _button_press;

/*****************************************************************************
 * Function: BtnInit
 *
 * Preconditon: None.
 *
 * Overview: Setup debounce.
 *
 * Input: None.
 *
 * Output: None.
 *
 *****************************************************************************/
void BtnInit(void)
{
	_b1_cnt = 128;
	_b2_cnt = 128;
	_b3_cnt = 128;
	_b4_cnt = 128;
	_b5_cnt = 128;
	_button_press.b1 = 0;
	_button_press.b2 = 0;
	_button_press.b3 = 0;
	_button_press.b4 = 0;
	///****added for backlight swtich and control
//		TRISBbits.TRISB12 =1;   //button five input
//		BLACKLIGHT =0; //start out low for control
//		TRISBbits.TRISB13 =0;  //transistor control
		
	
}

/*****************************************************************************
 * Function: BtnProcessEvents
 *
 * Preconditon: None.
 *
 * Overview: Must be called periodically to proccess buttons.
 *
 * Input: None.
 *
 * Output: None.
 Button are mux with LCD data lines and so must be switched to input
 and output on return
 *
 *****************************************************************************/
void BtnProcessEvents(void)
{
	//switch to inputs
	LATAbits.LATA0 =1;
		TRISAbits.TRISA0=1;
		TRISAbits.TRISA1=1;
		TRISAbits.TRISA2=1;
		TRISAbits.TRISA3=1;
	
		if (!BUTTON1) {
		_b1_cnt++;
		if (_b1_cnt > (128 + BUTTON_MAX_DEBOUCE)){
			_b1_cnt = (128 + BUTTON_MAX_DEBOUCE);
			_button_press.b1 = 1;
		}		
	}
	else {
		_b1_cnt--;
		if (_b1_cnt < (128 - BUTTON_MAX_DEBOUCE)){
			_b1_cnt = (128 - BUTTON_MAX_DEBOUCE);
			_button_press.b1 = 0;
		}
	}
 

	if (!BUTTON2) {
		_b2_cnt++;
		if (_b2_cnt > (128 + BUTTON_MAX_DEBOUCE)){
			_b2_cnt = (128 + BUTTON_MAX_DEBOUCE);
			_button_press.b2 = 1;
		}
	}
	else {
		_b2_cnt--;
		if (_b2_cnt < (128 - BUTTON_MAX_DEBOUCE)){
			_b2_cnt = (128 - BUTTON_MAX_DEBOUCE);
			_button_press.b2 = 0;
		}
	}


	if (!BUTTON3) {
		_b3_cnt++;
		if (_b3_cnt > (128 + BUTTON_MAX_DEBOUCE)){
			_b3_cnt = (128 + BUTTON_MAX_DEBOUCE);
			_button_press.b3 = 1;
		}
	}
	else {
		_b3_cnt--;
		if (_b3_cnt < (128 - BUTTON_MAX_DEBOUCE)){
			_b3_cnt = (128 - BUTTON_MAX_DEBOUCE);
			_button_press.b3 = 0;
		}
	}


	if (!BUTTON4) {
		_b4_cnt++;
		if (_b4_cnt > (128 + BUTTON_MAX_DEBOUCE)){
			_b4_cnt = (128 + BUTTON_MAX_DEBOUCE);
			_button_press.b4 = 1;
		}
	}
	else {
		_b4_cnt--;
		if (_b4_cnt < (128 - BUTTON_MAX_DEBOUCE)){
			_b4_cnt = (128 - BUTTON_MAX_DEBOUCE);
			_button_press.b4 = 0;
		}
		
}

//	switch back to outputs
//	LATAbits.LATA0 =0;
	TRISAbits.TRISA0=0;
//	LATAbits.LATA1 =0;
	TRISAbits.TRISA1=0;
//	LATAbits.LATA2 =0;
	TRISAbits.TRISA2=0;
//	LATAbits.LATA3 =0;
	TRISAbits.TRISA3=0;
}
//***************quickie button check**********************************
void QBtnProcessEvents(void)
{
	//switch to inputs
	LATAbits.LATA0 =1;
		TRISAbits.TRISA0=1;
		LATAbits.LATA1 =1;	
		TRISAbits.TRISA1=1;
		LATAbits.LATA2 =1;		
		TRISAbits.TRISA2=1;
			LATAbits.LATA3 =1;	
		TRISAbits.TRISA3=1;
	
		if (!BUTTON1) 
		{	AdcFlag =1;
			_button_press.b1 = 1;
		}		
	
	else 
		{
		//	AdcFlag =0;
			_button_press.b1 = 0;
		}
	
 

	if (!BUTTON2) 
		{	LightShowFlag =1;
			_button_press.b2 = 1;
		}
	else 
		{//	LightShowFlag =0;
			_button_press.b2 = 0;
		}
	


	if (!BUTTON3) 
	      {  ClockFlag =1;
			_button_press.b3 = 1;
	
		}
	else 
	
		{//	ClockFlag =0;
			_button_press.b3 = 0;
		}



	if (!BUTTON4) 
		{
			_button_press.b4 = 1;
				AdcFlag =0;
				LightShowFlag =0;
				ClockFlag =0;
				
		}
	else 
		{
			_button_press.b4 = 0;
		}	


//	switch back to outputs
//	LATAbits.LATA0 =0;
	TRISAbits.TRISA0=0;
//	LATAbits.LATA1 =0;
	TRISAbits.TRISA1=0;
//	LATAbits.LATA2 =0;
	TRISAbits.TRISA2=0;
//	LATAbits.LATA3 =0;
	TRISAbits.TRISA3=0;
}











//***********************************************************************
//back light on/off
void toggle_BL(void) {
	
 BL_ON ^=1;	
 BLACKLIGHT =BL_ON;
 
	
}	
/*****************************************************************************
 * EOF
 *****************************************************************************/

